@@ -1,13 +1,14 @@
 package PNI::Core;
 
-our $VERSION = '0.06.2';
+use 5.10.1;
 
-1
-__END__
+our $VERSION = '0.01';
+
+1;
 
 =head1 NAME
 
-PNI::Core - Perl Node Interface core bundle
+PNI::Core - Perl Node Interface core distribution
 
 =head1 SYNOPSIS
 
@@ -15,7 +16,7 @@ PNI::Core - Perl Node Interface core bundle
 
 =head1 DESCRIPTION
 
-Installs L<PNI>  and a default set of PNI nodes.
+Install L<PNI> core modules and a default set of PNI nodes.
 
 This module also requires Perl version greater or equal than 5.10.1,
 
